pub enum FunctionDef {
Expr(FunctionExpression),
Conditioned(Vec<ConditionedFunctionExpression>),
}Expand description
Function Definition
The definition of a function. This can be an expression or a conditioned function.
Variants
Expr(FunctionExpression)
Conditioned(Vec<ConditionedFunctionExpression>)
Conditioned Function
A function defined as list of function expression with conditions (time range, space range, etc…). The function expressions are checked in order. Therefore, in case of an overlap, the first one will be used. If no function expressions without conditions are specified, a default value of 0 will be assumed.