pub struct HyperCubeMesh {
pub range: Range<Length>,
pub resolution: Length,
pub show_info: bool,
}Fields
range: Range<Length>resolution: LengthResolution
The size of each cell.
show_info: boolTrait Implementations
Sourceimpl Clone for HyperCubeMesh
impl Clone for HyperCubeMesh
Sourcefn clone(&self) -> HyperCubeMesh
fn clone(&self) -> HyperCubeMesh
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HyperCubeMesh
impl Debug for HyperCubeMesh
Sourceimpl Default for HyperCubeMesh
impl Default for HyperCubeMesh
Sourceimpl<'de> Deserialize<'de> for HyperCubeMeshwhere
HyperCubeMesh: Default,
impl<'de> Deserialize<'de> for HyperCubeMeshwhere
HyperCubeMesh: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HyperCubeMesh
impl JsonSchema for HyperCubeMesh
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Mesh for HyperCubeMesh
impl Mesh for HyperCubeMesh