pub struct CustomQuantity {
pub length: isize,
pub time: isize,
pub mass: isize,
pub current: isize,
pub temperature: isize,
pub amount: isize,
pub luminous_intensity: isize,
pub value: f64,
}Expand description
CustomQuantity
This allows defining custom quantities based on the seven base quantities of the international system.
Fields
length: isizetime: isizemass: isizecurrent: isizetemperature: isizeamount: isizeluminous_intensity: isizevalue: f64Trait Implementations
Sourceimpl Clone for CustomQuantity
impl Clone for CustomQuantity
Sourcefn clone(&self) -> CustomQuantity
fn clone(&self) -> CustomQuantity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomQuantity
impl Debug for CustomQuantity
Sourceimpl Default for CustomQuantity
impl Default for CustomQuantity
Sourcefn default() -> CustomQuantity
fn default() -> CustomQuantity
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CustomQuantity
impl<'de> Deserialize<'de> for CustomQuantity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CustomQuantity
impl JsonSchema for CustomQuantity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CustomQuantity
impl RefUnwindSafe for CustomQuantity
impl Send for CustomQuantity
impl Sync for CustomQuantity
impl Unpin for CustomQuantity
impl UnwindSafe for CustomQuantity