pub struct WithRawRepr<L> { /* private fields */ }Trait Implementations
Sourceimpl<L: Clone> Clone for WithRawRepr<L>
impl<L: Clone> Clone for WithRawRepr<L>
Sourcefn clone(&self) -> WithRawRepr<L>
fn clone(&self) -> WithRawRepr<L>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<L: Debug> Debug for WithRawRepr<L>
impl<L: Debug> Debug for WithRawRepr<L>
Sourceimpl<L> DerefMut for WithRawRepr<L>
impl<L> DerefMut for WithRawRepr<L>
Sourceimpl<'de, T> Deserialize<'de> for WithRawRepr<T>
impl<'de, T> Deserialize<'de> for WithRawRepr<T>
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> Display for WithRawRepr<T>
impl<T> Display for WithRawRepr<T>
Sourceimpl<T: FromStr> FromStr for WithRawRepr<T>
impl<T: FromStr> FromStr for WithRawRepr<T>
Sourceimpl<T: JsonSchema> JsonSchema for WithRawRepr<T>
impl<T: JsonSchema> JsonSchema for WithRawRepr<T>
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl<L: PartialEq> PartialEq for WithRawRepr<L>
impl<L: PartialEq> PartialEq for WithRawRepr<L>
Sourceimpl<L: PartialOrd> PartialOrd for WithRawRepr<L>
impl<L: PartialOrd> PartialOrd for WithRawRepr<L>
Sourceimpl<T> Serialize for WithRawRepr<T>
impl<T> Serialize for WithRawRepr<T>
Sourceimpl<L> Deref for WithRawRepr<L>
impl<L> Deref for WithRawRepr<L>
impl<L> StructuralPartialEq for WithRawRepr<L>