pub type Length = WithRawRepr<Quantity<Length>>;Expand description
Length (default: kilometers, since distances in geoscience are often measured in km)
Aliased Type
pub struct Length { /* private fields */ }pub type Length = WithRawRepr<Quantity<Length>>;Length (default: kilometers, since distances in geoscience are often measured in km)
pub struct Length { /* private fields */ }