pub type Ratio = WithRawRepr<Ratio>;Expand description
Ratio (unit less value resulting from calculating the ratio of two quantities)
Aliased Type
pub struct Ratio { /* private fields */ }pub type Ratio = WithRawRepr<Ratio>;Ratio (unit less value resulting from calculating the ratio of two quantities)
pub struct Ratio { /* private fields */ }