pub struct ConditionedFunctionExpression {
pub expr: FunctionExpression,
pub t: Option<Condition<Time>>,
pub x: Option<Condition<Length>>,
pub y: Option<Condition<Length>>,
pub z: Option<Condition<Length>>,
}Fields
expr: FunctionExpressiont: Option<Condition<Time>>Time Condition
The time condition for which the function expression is valid. It can be none, a value or a range.
x: Option<Condition<Length>>X Condition
The x condition for which the function expression is valid. It can be none, a value or a range.
y: Option<Condition<Length>>Y Condition
The y condition for which the function expression is valid. It can be none, a value or a range.
z: Option<Condition<Length>>Z Condition
The z condition for which the function expression is valid. It can be none, a value or a range.