FunctionExpression

Struct FunctionExpression 

pub struct FunctionExpression(/* private fields */);
Function Expression

A function expression. Available variables are : t, x, y, z. Math functions such as cosinus or exponentials are available. They can be called through their cpp names like log for the logarithm.