pub struct Unknown {
pub initial: UnknownProperty,
pub boundary: UnknownProperty,
pub derivative: Option<Box<Unknown>>,
}Expand description
Unknown
Represents an unknown to be solved in the PDE.
Fields
initial: UnknownPropertyInitial Condition
The initial value of the unknown.
boundary: UnknownPropertyBoundary Condition
The boundary condition of the unknown.
derivative: Option<Box<Unknown>>Time Derivative Conditions
The time derivative’s conditions of the unknown. The number of derivative specified should match the max time order of the equations - 1. (ie. an equation of order 2 in time needs one derivative specified)
Implementations
Sourceimpl Unknown
impl Unknown
pub fn visit_symbols<E, F: Fn(&str) -> Result<(), E>>( &self, f: F, ) -> Result<(), E>
pub fn has_symbol(&self, s: &str) -> bool
pub fn visit_props<E: StdError, F: FnMut(&UnknownProperty) -> Result<(), E>>( &self, f: F, ) -> Result<(), E>
pub fn visit_constants<E: StdError, F: FnMut(ConstantFunction) -> Result<(), E>>( &self, f: F, ) -> Result<(), E>